@@ -19,6 +19,7 @@
 package org.apache.celeborn.plugin.flink;
 
 import static org.apache.celeborn.plugin.flink.utils.Utils.checkState;
+import static org.apache.flink.runtime.metrics.groups.ShuffleIOMetricGroup.createShuffleIOMetricGroup;
 
 import java.io.IOException;
 import java.util.*;
@@ -41,7 +42,10 @@ import org.apache.flink.runtime.io.network.buffer.BufferPool;
 import org.apache.flink.runtime.io.network.partition.PartitionNotFoundException;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
 import org.apache.flink.runtime.io.network.partition.consumer.BufferOrEvent;
+import org.apache.flink.runtime.io.network.partition.consumer.PartitionConnectionException;
+import org.apache.flink.runtime.metrics.groups.ShuffleIOMetricGroup;
 import org.apache.flink.runtime.shuffle.ShuffleDescriptor;
+import org.apache.flink.runtime.shuffle.ShuffleIOOwnerContext;
 import org.apache.flink.shaded.netty4.io.netty.buffer.ByteBuf;
 import org.apache.flink.util.ExceptionUtils;
 import org.apache.flink.util.function.SupplierWithException;
@@ -54,13 +58,13 @@ import org.apache.celeborn.common.exception.PartitionUnRetryAbleException;
 import org.apache.celeborn.common.identity.UserIdentifier;
 import org.apache.celeborn.plugin.flink.buffer.BufferPacker;
 import org.apache.celeborn.plugin.flink.buffer.TransferBufferPool;
-import org.apache.celeborn.plugin.flink.readclient.FlinkShuffleClientImpl;
+import org.apache.celeborn.plugin.flink.client.FlinkShuffleClientImpl;
 import org.apache.celeborn.plugin.flink.utils.BufferUtils;
 
 public class RemoteShuffleInputGateDelegation {
   private static final Logger LOG = LoggerFactory.getLogger(RemoteShuffleInputGateDelegation.class);
   /** Lock to protect {@link #receivedBuffers} and {@link #cause} and {@link #closed}. */
-  private Object lock = new Object();
+  private final Object lock = new Object();
 
   /** Name of the corresponding computing task. */
   private String taskName;
@@ -127,10 +131,13 @@ public class RemoteShuffleInputGateDelegation {
   private AvailabilityProvider.AvailabilityHelper availabilityHelper;
   private int startSubIndex;
   private int endSubIndex;
+  private boolean partitionConnectionExceptionEnabled;
+
+  private final ShuffleIOMetricGroup shuffleIOMetricGroup;
 
   public RemoteShuffleInputGateDelegation(
       CelebornConf celebornConf,
-      String taskName,
+      ShuffleIOOwnerContext ownerContext,
       int gateIndex,
       InputGateDeploymentDescriptor gateDescriptor,
       SupplierWithException<BufferPool, IOException> bufferPoolFactory,
@@ -138,8 +145,9 @@ public class RemoteShuffleInputGateDelegation {
       int numConcurrentReading,
       AvailabilityProvider.AvailabilityHelper availabilityHelper,
       int startSubIndex,
-      int endSubIndex) {
-    this.taskName = taskName;
+      int endSubIndex,
+      Map<Integer, ShuffleIOMetricGroup> shuffleIOMetricGroups) {
+    this.taskName = ownerContext.getOwnerName();
     this.gateIndex = gateIndex;
     this.gateDescriptor = gateDescriptor;
     this.bufferPoolFactory = bufferPoolFactory;
@@ -153,6 +161,14 @@ public class RemoteShuffleInputGateDelegation {
     RemoteShuffleDescriptor remoteShuffleDescriptor =
         (RemoteShuffleDescriptor) gateDescriptor.getShuffleDescriptors()[0];
     RemoteShuffleResource shuffleResource = remoteShuffleDescriptor.getShuffleResource();
+    int shuffleId =
+        remoteShuffleDescriptor
+            .getShuffleResource()
+            .getMapPartitionShuffleDescriptor()
+            .getShuffleId();
+    this.shuffleIOMetricGroup =
+        shuffleIOMetricGroups.computeIfAbsent(
+            shuffleId, k -> createShuffleIOMetricGroup(ownerContext, shuffleId, celebornConf));
 
     try {
       String appUniqueId =
@@ -177,6 +193,7 @@ public class RemoteShuffleInputGateDelegation {
     channelsInfo = createChannelInfos();
     this.numConcurrentReading = numConcurrentReading;
     this.availabilityHelper = availabilityHelper;
+    this.partitionConnectionExceptionEnabled = celebornConf.partitionConnectionExceptionEnabled();
     LOG.debug("Initial input gate with numConcurrentReading {}", this.numConcurrentReading);
   }
 
@@ -205,7 +222,7 @@ public class RemoteShuffleInputGateDelegation {
               startSubIndex,
               endSubIndex,
               transferBufferPool,
-              getDataListener(descriptor.getLeft()),
+              getDataListener(descriptor.getLeft(), shuffleIOMetricGroup),
               getFailureListener(remoteDescriptor.getResultPartitionID()));
 
       bufferReaders.add(reader);
@@ -232,13 +249,14 @@ public class RemoteShuffleInputGateDelegation {
         .collect(Collectors.toList());
   }
 
-  private Consumer<ByteBuf> getDataListener(int channelIdx) {
+  private Consumer<ByteBuf> getDataListener(
+      int channelIdx, ShuffleIOMetricGroup shuffleIOMetricGroup) {
     return byteBuf -> {
       Queue<Buffer> unpackedBuffers = null;
       try {
         unpackedBuffers = BufferPacker.unpack(byteBuf);
         while (!unpackedBuffers.isEmpty()) {
-          onBuffer(unpackedBuffers.poll(), channelIdx);
+          onBuffer(unpackedBuffers.poll(), channelIdx, shuffleIOMetricGroup);
         }
       } catch (Throwable throwable) {
         synchronized (lock) {
@@ -261,8 +279,13 @@ public class RemoteShuffleInputGateDelegation {
           return;
         }
         Class<?> clazz = PartitionUnRetryAbleException.class;
-        if (throwable.getMessage() != null && throwable.getMessage().contains(clazz.getName())) {
+        String message = throwable.getMessage();
+        if (null != message && message.contains(clazz.getName())) {
           cause = new PartitionNotFoundException(rpID);
+        } else if (partitionConnectionExceptionEnabled
+            && null != message
+            && message.contains("Failed to connect to")) {
+          cause = new PartitionConnectionException(rpID, throwable);
         } else {
           cause = throwable;
         }
@@ -271,7 +294,7 @@ public class RemoteShuffleInputGateDelegation {
     };
   }
 
-  private void onBuffer(Buffer buffer, int channelIdx) {
+  private void onBuffer(Buffer buffer, int channelIdx, ShuffleIOMetricGroup shuffleIOMetricGroup) {
     synchronized (lock) {
       if (closed || cause != null) {
         buffer.recycleBuffer();
@@ -285,6 +308,7 @@ public class RemoteShuffleInputGateDelegation {
         checkState(channelInfo.getInputChannelIdx() == channelIdx, "Illegal channel index.");
         LOG.debug("ReceivedBuffers is adding buffer {} on {}", buffer, channelInfo);
         receivedBuffers.add(Pair.of(buffer, channelInfo));
+        shuffleIOMetricGroup.getNumBytesIn().inc(buffer.getSize());
         needRecycle = false;
         if (wasEmpty) {
           availabilityHelper.getUnavailableToResetAvailable().complete(null);
@@ -440,7 +464,8 @@ public class RemoteShuffleInputGateDelegation {
     try {
       event = EventSerializer.fromBuffer(buffer, getClass().getClassLoader());
     } catch (Throwable t) {
-      throw new IOException("Deserialize failure.", t);
+      LOG.error("Failed to deserialize event: inputChannelInfo {}.", channelInfo, t);
+      throw new PartitionNotFoundException(channelToResultPartitionId.get(channelInfo));
     } finally {
       buffer.recycleBuffer();
     }
