@@ -20,6 +20,7 @@ package org.apache.celeborn.plugin.flink;
 import java.io.IOException;
 import java.util.List;
 
+import org.apache.flink.configuration.NettyShuffleEnvironmentOptions;
 import org.apache.flink.runtime.io.network.buffer.BufferCompressor;
 import org.apache.flink.runtime.io.network.buffer.BufferPool;
 import org.apache.flink.runtime.io.network.buffer.BufferPoolFactory;
@@ -27,9 +28,11 @@ import org.apache.flink.runtime.io.network.partition.ResultPartition;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionID;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionManager;
 import org.apache.flink.runtime.io.network.partition.ResultPartitionType;
+import org.apache.flink.runtime.metrics.groups.ShuffleIOMetricGroup;
 import org.apache.flink.util.function.SupplierWithException;
 
 import org.apache.celeborn.common.CelebornConf;
+import org.apache.celeborn.common.protocol.CompressionCodec;
 
 /** Factory class to create {@link RemoteShuffleResultPartition}. */
 public class RemoteShuffleResultPartitionFactory
@@ -56,7 +59,8 @@ public class RemoteShuffleResultPartitionFactory
       CelebornConf celebornConf,
       int numMappers,
       BufferCompressor bufferCompressor,
-      RemoteShuffleDescriptor rsd) {
+      RemoteShuffleDescriptor rsd,
+      ShuffleIOMetricGroup shuffleIOMetricGroup) {
     return new RemoteShuffleResultPartition(
         taskNameWithSubtaskAndId,
         partitionIndex,
@@ -74,6 +78,16 @@ public class RemoteShuffleResultPartitionFactory
             networkBufferSize,
             bufferPoolFactories.get(1),
             celebornConf,
-            numMappers));
+            numMappers,
+            shuffleIOMetricGroup));
+  }
+
+  @Override
+  protected BufferCompressor getBufferCompressor() {
+    return CompressionCodec.NONE.name().equals(compressionCodec)
+        ? null
+        : new BufferCompressor(
+            networkBufferSize,
+            NettyShuffleEnvironmentOptions.CompressionCodec.valueOf(compressionCodec));
   }
 }
