@@ -386,7 +386,7 @@ public abstract class CelebornInputStream extends InputStream {
       }
       currentReader = createReaderWithRetry(currentLocation._1, currentLocation._2);
       fileIndex++;
-      while (!currentReader.hasNext()) {
+      while (!currentReader.hasNext() || (fetchChunk && (currentChunk = getNextChunk()) == null)) {
         currentReader.close();
         currentReader = null;
         currentLocation = nextReadableLocation();
@@ -396,9 +396,6 @@ public abstract class CelebornInputStream extends InputStream {
         currentReader = createReaderWithRetry(currentLocation._1, currentLocation._2);
         fileIndex++;
       }
-      if (fetchChunk) {
-        currentChunk = getNextChunk();
-      }
     }
 
     private boolean isExcluded(PartitionLocation location) {
@@ -507,6 +504,9 @@ public abstract class CelebornInputStream extends InputStream {
             throw new CelebornIOException(
                 "Fetch data from excluded worker! " + currentReader.getLocation());
           }
+          if (!currentReader.hasNext()) {
+            return null;
+          }
           return currentReader.next();
         } catch (Exception e) {
           shuffleClient.excludeFailedFetchLocation(
@@ -726,8 +726,7 @@ public abstract class CelebornInputStream extends InputStream {
         currentChunk.release();
       }
       currentChunk = null;
-      if (currentReader.hasNext()) {
-        currentChunk = getNextChunk();
+      if (currentReader.hasNext() && (currentChunk = getNextChunk()) != null) {
         return true;
       } else if (fileIndex < locations.size()) {
         moveToNextReader(true);
@@ -757,6 +756,7 @@ public abstract class CelebornInputStream extends InputStream {
         if (firstChunk && currentReader != null) {
           init();
           currentChunk = getNextChunk();
+          while (currentChunk == null && moveToNextChunk()) ;
           firstChunk = false;
         }
         if (currentChunk == null) {
