@@ -335,7 +335,7 @@ abstract class CommitHandler(
           status.future.value.get match {
             case scala.util.Success(res) =>
               res.status match {
-                case StatusCode.SUCCESS | StatusCode.PARTIAL_SUCCESS | StatusCode.SHUFFLE_NOT_REGISTERED | StatusCode.REQUEST_FAILED | StatusCode.WORKER_EXCLUDED | StatusCode.COMMIT_FILE_EXCEPTION =>
+                case StatusCode.SUCCESS | StatusCode.PARTIAL_SUCCESS | StatusCode.SHUFFLE_UNREGISTERED | StatusCode.REQUEST_FAILED | StatusCode.WORKER_EXCLUDED | StatusCode.COMMIT_FILE_EXCEPTION =>
                   if (res.status == StatusCode.SUCCESS) {
                     logDebug(s"Request commitFiles return ${res.status} for " +
                       s"$shuffleKey from worker ${worker.readableAddress()}")
