@@ -483,7 +483,7 @@ public class ShuffleClientSuiteJ {
         .thenAnswer(
             t -> {
               return GetReducerFileGroupResponse$.MODULE$.apply(
-                  StatusCode.SHUFFLE_NOT_REGISTERED,
+                  StatusCode.SHUFFLE_UNREGISTERED,
                   locations,
                   new int[0],
                   Collections.emptySet(),
@@ -496,7 +496,7 @@ public class ShuffleClientSuiteJ {
         .thenAnswer(
             t -> {
               return GetReducerFileGroupResponse$.MODULE$.apply(
-                  StatusCode.SHUFFLE_NOT_REGISTERED,
+                  StatusCode.SHUFFLE_UNREGISTERED,
                   locations,
                   new int[0],
                   Collections.emptySet(),
@@ -519,7 +519,7 @@ public class ShuffleClientSuiteJ {
         .thenAnswer(
             t -> {
               return GetReducerFileGroupResponse$.MODULE$.apply(
-                  StatusCode.STAGE_END_TIME_OUT,
+                  StatusCode.STAGE_END_TIMEOUT,
                   locations,
                   new int[0],
                   Collections.emptySet(),
@@ -532,7 +532,7 @@ public class ShuffleClientSuiteJ {
         .thenAnswer(
             t -> {
               return GetReducerFileGroupResponse$.MODULE$.apply(
-                  StatusCode.STAGE_END_TIME_OUT,
+                  StatusCode.STAGE_END_TIMEOUT,
                   locations,
                   new int[0],
                   Collections.emptySet(),
