@@ -111,6 +111,19 @@ public class TransportContext implements Closeable {
     this(conf, msgHandler, closeIdleConnections, null, enableHeartbeat, source);
   }
 
+  public TransportContext(
+      TransportConf conf,
+      BaseMessageHandler msgHandler,
+      boolean closeIdleConnections,
+      boolean enableHeartbeat,
+      AbstractSource source,
+      boolean collectFetchChunkDetailMetrics) {
+    this(conf, msgHandler, closeIdleConnections, null, enableHeartbeat, source);
+    if (collectFetchChunkDetailMetrics) {
+      ENCODER.setSource(source);
+    }
+  }
+
   public TransportContext(
       TransportConf conf, BaseMessageHandler msgHandler, boolean closeIdleConnections) {
     this(conf, msgHandler, closeIdleConnections, null, false, null);
@@ -230,7 +243,7 @@ public class TransportContext implements Closeable {
         conf.connectionTimeoutMs(),
         closeIdleConnections,
         enableHeartbeat,
-        conf.clientHeartbeatInterval(),
+        conf.channelHeartbeatInterval(),
         this);
   }
 
