@@ -460,6 +460,14 @@ public class JavaUtils {
     }
   }
 
+  public static <K, V> ConcurrentHashMap<K, V> newConcurrentHashMap(int initialCapacity) {
+    if (SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_9)) {
+      return new ConcurrentHashMap<>(initialCapacity);
+    } else {
+      return new ConcurrentHashMapForJDK8<>(initialCapacity);
+    }
+  }
+
   /**
    * For JDK8, there is bug for ConcurrentHashMap#computeIfAbsent, checking the key existence to
    * speed up. See details in CELEBORN-474.
@@ -469,6 +477,10 @@ public class JavaUtils {
       super();
     }
 
+    public ConcurrentHashMapForJDK8(int initialCapacity) {
+      super(initialCapacity);
+    }
+
     public ConcurrentHashMapForJDK8(Map<? extends K, ? extends V> m) {
       super(m);
     }
