@@ -109,9 +109,13 @@ abstract class AbstractSource(conf: CelebornConf, role: String)
       gauge: Gauge[T]): Unit = {
     // filter out non-number type gauges
     if (gauge.getValue.isInstanceOf[Number]) {
-      namedGauges.putIfAbsent(
-        metricNameWithCustomizedLabels(name, labels),
-        NamedGauge(name, gauge, labels ++ staticLabels))
+      val metricNameWithLabel = metricNameWithCustomizedLabels(name, labels)
+      namedGauges.putIfAbsent(metricNameWithLabel, NamedGauge(name, gauge, labels ++ staticLabels))
+      metricRegistry.synchronized({
+        if (!metricRegistry.getMetrics.containsKey(metricNameWithLabel)) {
+          metricRegistry.register(metricNameWithLabel, gauge)
+        }
+      })
     } else {
       logWarning(
         s"Add gauge $name failed, the value type ${gauge.getValue.getClass} is not a number")
