@@ -18,7 +18,7 @@
 package org.apache.celeborn.common.protocol.message
 
 import java.util
-import java.util.{Collections, UUID}
+import java.util.{Collections, Map => JMap, UUID}
 
 import scala.collection.JavaConverters._
 
@@ -417,6 +417,13 @@ object ControlMessages extends Logging {
 
   case class ApplicationLostResponse(status: StatusCode) extends MasterMessage
 
+  case class RegisterApplicationInfo(
+      applicationId: String,
+      userIdentifier: UserIdentifier,
+      extraInfo: JMap[String, String],
+      override var requestId: String = ZERO_UUID)
+    extends MasterRequestMessage
+
   case class HeartbeatFromApplication(
       appId: String,
       totalWritten: Long,
@@ -843,6 +850,19 @@ object ControlMessages extends Logging {
         .setStatus(status.getValue).build().toByteArray
       new TransportMessage(MessageType.APPLICATION_LOST_RESPONSE, payload)
 
+    case RegisterApplicationInfo(
+          applicationId,
+          userIdentifier,
+          extraInfo,
+          requestId) =>
+      val payload = PbRegisterApplicationInfo.newBuilder()
+        .setAppId(applicationId)
+        .setUserIdentifier(PbSerDeUtils.toPbUserIdentifier(userIdentifier))
+        .putAllExtraInfo(extraInfo)
+        .setRequestId(requestId)
+        .build().toByteArray
+      new TransportMessage(MessageType.REGISTER_APPLICATION_INFO, payload)
+
     case HeartbeatFromApplication(
           appId,
           totalWritten,
@@ -1477,6 +1497,13 @@ object ControlMessages extends Logging {
 
       case GET_STAGE_END_RESPONSE_VALUE =>
         PbGetStageEndResponse.parseFrom(message.getPayload)
+
+      case REGISTER_APPLICATION_INFO_VALUE =>
+        val pbRegisterApplicationInfo = PbRegisterApplicationInfo.parseFrom(message.getPayload)
+        RegisterApplicationInfo(
+          pbRegisterApplicationInfo.getAppId,
+          PbSerDeUtils.fromPbUserIdentifier(pbRegisterApplicationInfo.getUserIdentifier),
+          pbRegisterApplicationInfo.getExtraInfoMap)
     }
   }
 }
