@@ -33,14 +33,15 @@ import org.apache.celeborn.common.util.{JavaUtils, ThreadUtils}
 /**
  * A message dispatcher, responsible for routing RPC messages to the appropriate endpoint(s).
  */
-private[celeborn] class Dispatcher(nettyEnv: NettyRpcEnv) extends Logging {
+private[celeborn] class Dispatcher(nettyEnv: NettyRpcEnv, rpcSource: RpcSource) extends Logging {
 
   private class EndpointData(
       val name: String,
       val endpoint: RpcEndpoint,
       val ref: NettyRpcEndpointRef) {
     val celebornConf = nettyEnv.celebornConf
-    val inbox = new Inbox(ref, endpoint, celebornConf)
+    val inbox =
+      new Inbox(ref, endpoint, celebornConf, new RpcMetricsTracker(name, rpcSource, celebornConf))
   }
 
   private val endpoints: ConcurrentMap[String, EndpointData] =
@@ -216,7 +217,7 @@ private[celeborn] class Dispatcher(nettyEnv: NettyRpcEnv) extends Logging {
     val numThreads = nettyEnv.celebornConf.rpcDispatcherNumThreads(availableCores, role)
 
     val pool = ThreadUtils.newDaemonFixedThreadPool(numThreads, "celeborn-dispatcher")
-    logInfo(s"Dispatcher numThreads: $numThreads")
+    logInfo(s"Celeborn dispatcher numThreads: $numThreads")
     for (i <- 0 until numThreads) {
       pool.execute(new MessageLoop)
     }
