@@ -39,6 +39,7 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.celeborn.common.CelebornConf;
 import org.apache.celeborn.common.identity.UserIdentifier;
+import org.apache.celeborn.common.meta.ApplicationInfo;
 import org.apache.celeborn.common.meta.ApplicationMeta;
 import org.apache.celeborn.common.meta.DiskInfo;
 import org.apache.celeborn.common.meta.DiskStatus;
@@ -96,9 +97,17 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
   public final Map<String, Long> shuffleFallbackCounts = JavaUtils.newConcurrentHashMap();
   public final Map<String, Long> applicationFallbackCounts = JavaUtils.newConcurrentHashMap();
 
+  public final ConcurrentHashMap<String, ApplicationInfo> applicationInfos =
+      JavaUtils.newConcurrentHashMap();
   public final ConcurrentHashMap<String, ApplicationMeta> applicationMetas =
       JavaUtils.newConcurrentHashMap();
 
+  public void updateApplicationInfo(
+      String appId, UserIdentifier userIdentifier, Map<String, String> extraInfo) {
+    applicationInfos.putIfAbsent(
+        appId, new ApplicationInfo(appId, userIdentifier, extraInfo, System.currentTimeMillis()));
+  }
+
   public void updateRequestSlotsMeta(
       String shuffleKey, String hostName, Map<String, Map<String, Integer>> workerWithAllocations) {
     Tuple2<String, Object> appIdShuffleId = Utils.splitShuffleKey(shuffleKey);
@@ -170,6 +179,7 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
     registeredAppAndShuffles.remove(appId);
     appHeartbeatTime.remove(appId);
     applicationMetas.remove(appId);
+    applicationInfos.remove(appId);
   }
 
   @VisibleForTesting
@@ -294,7 +304,10 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
                 && !conf.hasOssStorage())
             || highWorkload)) {
       LOG.warn(
-          "Worker {} (unhealthy disks num: {}) adds to excluded workers", worker, unhealthyDiskNum);
+          "Worker {} (unhealthy disks num: {}, high workload: {}) adds to excluded workers",
+          worker,
+          unhealthyDiskNum,
+          highWorkload);
       excludedWorkers.add(worker);
     } else if ((availableSlots.get() > 0
             || conf.hasHDFSStorage()
@@ -377,6 +390,7 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
                 shutdownWorkers,
                 workerEventInfos,
                 applicationMetas,
+                applicationInfos,
                 decommissionWorkers)
             .toByteArray();
     Files.write(file.toPath(), snapshotBytes);
@@ -482,6 +496,11 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
           .forEach(
               (key, value) -> applicationMetas.put(key, PbSerDeUtils.fromPbApplicationMeta(value)));
 
+      snapshotMetaInfo
+          .getApplicationInfosMap()
+          .forEach(
+              (key, value) -> applicationInfos.put(key, PbSerDeUtils.fromPbApplicationInfo(value)));
+
       availableWorkers.addAll(
           workersMap.values().stream()
               .filter(worker -> isWorkerAvailable(worker))
@@ -521,6 +540,7 @@ public abstract class AbstractMetaManager implements IMetadataHandler {
     applicationFallbackCounts.clear();
     workerEventInfos.clear();
     applicationMetas.clear();
+    applicationInfos.clear();
   }
 
   public void updateMetaByReportWorkerUnavailable(List<WorkerInfo> failedWorkers) {
