@@ -67,6 +67,34 @@ public class HAMasterMetaManager extends AbstractMetaManager {
     this.ratisServer = ratisServer;
   }
 
+  @Override
+  public void handleRegisterApplicationInfo(
+      String appId,
+      UserIdentifier userIdentifier,
+      Map<String, String> extraInfo,
+      String requestId) {
+    try {
+      ratisServer.submitRequest(
+          ResourceRequest.newBuilder()
+              .setCmdType(Type.RegisterApplicationInfo)
+              .setRequestId(requestId)
+              .setRegisterApplicationInfoRequest(
+                  ResourceProtos.RegisterApplicationInfoRequest.newBuilder()
+                      .setAppId(appId)
+                      .setUserIdentifier(
+                          ResourceProtos.UserIdentifier.newBuilder()
+                              .setTenantId(userIdentifier.tenantId())
+                              .setName(userIdentifier.name())
+                              .build())
+                      .putAllExtraInfo(extraInfo)
+                      .build())
+              .build());
+    } catch (CelebornRuntimeException e) {
+      LOG.error("Handle app lost for {} failed!", appId, e);
+      throw e;
+    }
+  }
+
   @Override
   public void handleRequestSlots(
       String shuffleKey,
