@@ -20,6 +20,7 @@ package org.apache.celeborn.service.deploy.master
 import java.io.IOException
 import java.net.BindException
 import java.util
+import java.util.{Map => JMap}
 import java.util.Collections
 import java.util.concurrent.{ExecutorService, ScheduledFuture, TimeUnit}
 import java.util.concurrent.atomic.AtomicBoolean
@@ -73,12 +74,16 @@ private[celeborn] class Master(
     new ResourceConsumptionSource(conf, Role.MASTER)
   private val threadPoolSource = ThreadPoolSource(conf, Role.MASTER)
   private val masterSource = new MasterSource(conf)
+  private val jvmSource = new JVMSource(conf, Role.MASTER)
+  private val jvmCpuSource = new JVMCPUSource(conf, Role.MASTER)
+  private val systemMiscSource = new SystemMiscSource(conf, Role.MASTER)
+
   metricsSystem.registerSource(resourceConsumptionSource)
   metricsSystem.registerSource(masterSource)
   metricsSystem.registerSource(threadPoolSource)
-  metricsSystem.registerSource(new JVMSource(conf, Role.MASTER))
-  metricsSystem.registerSource(new JVMCPUSource(conf, Role.MASTER))
-  metricsSystem.registerSource(new SystemMiscSource(conf, Role.MASTER))
+  metricsSystem.registerSource(jvmSource)
+  metricsSystem.registerSource(jvmCpuSource)
+  metricsSystem.registerSource(systemMiscSource)
 
   private val bindPreferIP: Boolean = conf.bindPreferIP
   private val authEnabled = conf.authEnabled
@@ -162,7 +167,7 @@ private[celeborn] class Master(
             logError(msg, ioe)
             System.exit(1)
           } else {
-            logError("Face unexpected IO exception during staring Ratis server", ioe)
+            logError("Face unexpected IO exception during starting Ratis server", ioe)
           }
       }
       sys
@@ -174,7 +179,7 @@ private[celeborn] class Master(
   // Threads
   private val forwardMessageThread =
     ThreadUtils.newDaemonSingleThreadScheduledExecutor("master-message-forwarder")
-  private var checkForWorkerTimeOutTask: ScheduledFuture[_] = _
+  private var checkForWorkerTimeoutTask: ScheduledFuture[_] = _
   private var checkForApplicationTimeOutTask: ScheduledFuture[_] = _
   private var checkForUnavailableWorkerTimeOutTask: ScheduledFuture[_] = _
   private var checkForDFSRemnantDirsTimeOutTask: ScheduledFuture[_] = _
@@ -336,7 +341,7 @@ private[celeborn] class Master(
         "send-application-meta")
     }
 
-    checkForWorkerTimeOutTask = scheduleCheckTask(workerHeartbeatTimeoutMs, pbCheckForWorkerTimeout)
+    checkForWorkerTimeoutTask = scheduleCheckTask(workerHeartbeatTimeoutMs, pbCheckForWorkerTimeout)
     checkForApplicationTimeOutTask =
       scheduleCheckTask(appHeartbeatTimeoutMs / 2, CheckForApplicationTimeOut)
 
@@ -370,7 +375,7 @@ private[celeborn] class Master(
       return
     }
     logInfo("Stopping Celeborn Master.")
-    Option(checkForWorkerTimeOutTask).foreach(_.cancel(true))
+    Option(checkForWorkerTimeoutTask).foreach(_.cancel(true))
     Option(checkForUnavailableWorkerTimeOutTask).foreach(_.cancel(true))
     Option(checkForApplicationTimeOutTask).foreach(_.cancel(true))
     Option(checkForDFSRemnantDirsTimeOutTask).foreach(_.cancel(true))
@@ -380,6 +385,9 @@ private[celeborn] class Master(
       sendApplicationMetaExecutor.shutdownNow()
     }
     messagesHelper.close()
+
+    metricsSystem.stop()
+
     logInfo("Celeborn Master is stopped.")
   }
 
@@ -421,6 +429,13 @@ private[celeborn] class Master(
   }
 
   override def receiveAndReply(context: RpcCallContext): PartialFunction[Any, Unit] = {
+    case RegisterApplicationInfo(appId, userIdentifier, extraInfo, requestId) =>
+      logDebug(
+        s"Received RegisterApplicationInfo request for app $appId/$userIdentifier/$extraInfo.")
+      checkAuth(context, appId)
+      executeWithLeaderChecker(
+        context,
+        handleRegisterApplicationInfo(context, appId, userIdentifier, extraInfo, requestId))
     case HeartbeatFromApplication(
           appId,
           totalWritten,
@@ -1154,6 +1169,16 @@ private[celeborn] class Master(
     }
   }
 
+  private def handleRegisterApplicationInfo(
+      context: RpcCallContext,
+      appId: String,
+      userIdentifier: UserIdentifier,
+      extraInfo: JMap[String, String],
+      requestId: String): Unit = {
+    statusSystem.handleRegisterApplicationInfo(appId, userIdentifier, extraInfo, requestId)
+    context.reply(OneWayMessageResponse)
+  }
+
   private def handleHeartbeatFromApplication(
       context: RpcCallContext,
       appId: String,
