@@ -1634,4 +1634,19 @@ public class RatisMasterStatusSystemSuiteJ {
     assertEquals(statusSystem.applicationFallbackCounts.get(POLICY1).longValue(), 2);
     assertEquals(statusSystem.applicationFallbackCounts.get(POLICY2).longValue(), 1);
   }
+
+  @Test
+  public void testRegisterApplicationInfo() {
+    AbstractMetaManager statusSystem = pickLeaderStatusSystem();
+    Assert.assertNotNull(statusSystem);
+    statusSystem.applicationInfos.clear();
+    UserIdentifier userIdentifier = new UserIdentifier("tenant", "celeborn");
+
+    String appId = "app1";
+    Map<String, String> extraInfo = Collections.singletonMap("k1", "v1");
+    statusSystem.handleRegisterApplicationInfo(appId, userIdentifier, extraInfo, getNewReqeustId());
+
+    assertEquals(statusSystem.applicationInfos.get(appId).userIdentifier(), userIdentifier);
+    assertEquals(statusSystem.applicationInfos.get(appId).extraInfo(), extraInfo);
+  }
 }
