@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 CREATE TABLE IF NOT EXISTS celeborn_cluster_info
 (
     id         int          NOT NULL AUTO_INCREMENT,
@@ -44,7 +45,7 @@ CREATE TABLE IF NOT EXISTS celeborn_cluster_tenant_config
     id           int          NOT NULL AUTO_INCREMENT,
     cluster_id   int          NOT NULL,
     tenant_id    varchar(255) NOT NULL,
-    level        varchar(255) NOT NULL COMMENT 'config level, valid level is TENANT,USER',
+    level        varchar(255) NOT NULL COMMENT 'config level, valid level is TENANT,TENANT_USER',
     name         varchar(255) DEFAULT NULL COMMENT 'tenant sub user',
     config_key   varchar(255) NOT NULL,
     config_value varchar(255) NOT NULL,
@@ -54,3 +55,15 @@ CREATE TABLE IF NOT EXISTS celeborn_cluster_tenant_config
     PRIMARY KEY (id),
     UNIQUE KEY `index_unique_tenant_config_key` (`cluster_id`, `tenant_id`, `name`, `config_key`)
 );
+
+CREATE TABLE IF NOT EXISTS celeborn_cluster_tags
+(
+    id         int          NOT NULL AUTO_INCREMENT,
+    cluster_id int          NOT NULL,
+    tag        varchar(255) NOT NULL,
+    worker_id  varchar(255) NOT NULL,
+    gmt_create timestamp    NOT NULL,
+    gmt_modify timestamp    NOT NULL,
+    PRIMARY KEY (id),
+    UNIQUE KEY `index_unique_cluster_tag_key` (`cluster_id`, `tag`, `worker_id`)
+);
