@@ -17,6 +17,7 @@
 
 package org.apache.celeborn.server.common.http
 
+import javax.servlet.http.HttpServletResponse
 import javax.ws.rs.core.MediaType
 
 import org.apache.celeborn.common.CelebornConf
@@ -30,13 +31,13 @@ abstract class ApiBaseResourceSuite extends HttpTestHelper {
 
   test("ping") {
     val response = webTarget.path("ping").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
     assert(response.readEntity(classOf[String]) == "pong")
   }
 
   test("conf") {
     val response = webTarget.path("conf").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("listDynamicConfigs") {
@@ -44,57 +45,59 @@ abstract class ApiBaseResourceSuite extends HttpTestHelper {
       .queryParam("LEVEL", "TENANT")
       .request(MediaType.TEXT_PLAIN)
       .get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("workerInfo") {
     val response = webTarget.path("workerInfo").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("threadDump") {
     val response = webTarget.path("threadDump").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("shuffle") {
     val response = webTarget.path("shuffle").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("applications") {
     val response = webTarget.path("applications").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
-  }
-
-  test("listTopDiskUsedApps") {
-    val response = webTarget.path("listTopDiskUsedApps").request(MediaType.TEXT_PLAIN).get()
-    assert(200 == response.getStatus)
-  }
-
-  test("openapi.json") {
-    val response = webTarget.path("openapi.json").request(MediaType.APPLICATION_JSON).get()
-    assert(200 == response.getStatus)
-    assert(response.readEntity(classOf[String]).contains("/conf"))
+    assert(HttpServletResponse.SC_OK == response.getStatus)
   }
 
   test("swagger") {
     Seq("swagger", "docs", "help").foreach { path =>
       val response = webTarget.path(path).request(MediaType.TEXT_HTML).get()
-      assert(200 == response.getStatus)
+      assert(HttpServletResponse.SC_OK == response.getStatus)
       assert(response.readEntity(classOf[String]).contains("swagger-ui"))
     }
+    Seq(
+      "openapi.json" -> MediaType.APPLICATION_JSON,
+      "openapi.yaml" -> "application/yaml").foreach { case (path, mediaType) =>
+      val response = webTarget.path(path).request(mediaType).get()
+      assert(HttpServletResponse.SC_OK == response.getStatus)
+      assert(response.readEntity(classOf[String]).contains("/conf"))
+    }
   }
 
-  test("metrics/prometheus") {
-    val response = webTarget.path("metrics/prometheus").request(MediaType.APPLICATION_JSON).get()
-    assert(200 == response.getStatus)
-    assert(response.readEntity(classOf[String]).contains("metrics_jvm_memory_heap_max_Value"))
-  }
+  test("metrics") {
+    var response = webTarget.path("metrics/prometheus").request(MediaType.APPLICATION_JSON).get()
+    assert(HttpServletResponse.SC_OK == response.getStatus)
+    val metricLines = response.readEntity(classOf[String]).split("\n")
+    Seq(
+      "metrics_jvm_memory_heap_max_Value",
+      "metrics_RpcQueueLength_Value",
+      "metrics_RpcQueueTime_Max",
+      "metrics_RpcProcessTime_Max").foreach { metric =>
+      assert(metricLines.exists(l =>
+        l.contains(metric) && l.contains(s"""instance="${httpService.connectionUrl}"""")))
+    }
 
-  test("metrics/json") {
-    val response = webTarget.path("metrics/json").request(MediaType.APPLICATION_JSON).get()
-    assert(200 == response.getStatus)
+    response = webTarget.path("metrics/json").request(MediaType.APPLICATION_JSON).get()
+    assert(HttpServletResponse.SC_OK == response.getStatus)
     assert(response.readEntity(classOf[String]).contains("\"name\" : \"jvm.memory.heap.max\""))
   }
 }
