@@ -23,14 +23,25 @@ public class RecyclableBuffer {
 
   public final ByteBuf byteBuf;
 
+  public final int subPartitionId;
+
   public final BufferRecycler bufferRecycler;
 
-  public RecyclableBuffer(ByteBuf byteBuf, BufferRecycler bufferRecycler) {
+  public RecyclableBuffer(ByteBuf byteBuf, int subPartitionId, BufferRecycler bufferRecycler) {
     this.byteBuf = byteBuf;
+    this.subPartitionId = subPartitionId;
     this.bufferRecycler = bufferRecycler;
   }
 
   public void recycle() {
     bufferRecycler.recycle(byteBuf);
   }
+
+  public int getSubPartitionId() {
+    return subPartitionId;
+  }
+
+  public boolean isDataBuffer() {
+    return true;
+  }
 }
