@@ -145,7 +145,9 @@ public class PartitionFilesSorter extends ShuffleRecoverHelper {
                 (key, cache) ->
                     ((Map<Integer, List<ShuffleBlockInfo>>) cache)
                         .values().stream().mapToInt(List::size).sum())
+            .recordStats()
             .build();
+    source.addGauge(WorkerSource.SORTER_CACHE_HIT_RATE(), () -> indexCache.stats().hitRate());
 
     fileSorterSchedulerThread =
         ThreadUtils.newDaemonSingleThreadExecutor("worker-file-sorter-scheduler");
@@ -269,9 +271,15 @@ public class PartitionFilesSorter extends ShuffleRecoverHelper {
             try {
               Thread.sleep(50);
               if (System.currentTimeMillis() - sortStartTime > sortTimeout) {
-                logger.error("Sorting file {} timeout after {}ms", fileId, sortTimeout);
-                throw new IOException(
-                    "Sort file " + diskFileInfo.getFilePath() + " timeout after " + sortTimeout);
+                String msg =
+                    String.format(
+                        "Sorting file %s path %s length %s timeout after %dms",
+                        fileId,
+                        diskFileInfo.getFilePath(),
+                        diskFileInfo.getFileLength(),
+                        sortTimeout);
+                logger.error(msg);
+                throw new IOException(msg);
               }
             } catch (InterruptedException e) {
               logger.error(
