@@ -157,7 +157,8 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
           conf.workerPushMaxComponents,
           diskInfo.mountPoint,
           diskInfo.storageType,
-          diskInfo.flushTimeMetrics)
+          diskInfo.flushTimeMetrics,
+          conf.workerFlusherBufferSize)
         flushers.put(diskInfo.mountPoint, flusher)
         totalThread = totalThread + diskInfo.threadCount
       }
@@ -184,7 +185,9 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
           workerSource,
           conf.workerHdfsFlusherThreads,
           storageBufferAllocator,
-          conf.workerPushMaxComponents)),
+          conf.workerPushMaxComponents,
+          conf.workerFlushReuseCopyBufferEnabled,
+          conf.workerHdfsFlusherBufferSize)),
         conf.workerHdfsFlusherThreads)
     } else {
       (None, 0)
@@ -205,7 +208,9 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
           workerSource,
           conf.workerS3FlusherThreads,
           storageBufferAllocator,
-          conf.workerPushMaxComponents)),
+          conf.workerPushMaxComponents,
+          conf.workerFlushReuseCopyBufferEnabled,
+          conf.workerS3FlusherBufferSize)),
         conf.workerS3FlusherThreads)
     } else {
       (None, 0)
@@ -226,7 +231,9 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
           workerSource,
           conf.workerOssFlusherThreads,
           storageBufferAllocator,
-          conf.workerPushMaxComponents)),
+          conf.workerPushMaxComponents,
+          conf.workerFlushReuseCopyBufferEnabled,
+          conf.workerOssFlusherBufferSize)),
         conf.workerOssFlusherThreads)
     } else {
       (None, 0)
@@ -468,10 +475,10 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
       try {
         new PartitionDataWriter(
           this,
+          workerSource,
           conf,
           deviceMonitor,
-          partitionDataWriterContext,
-          partitionType)
+          partitionDataWriterContext)
       } catch {
         case e: Exception =>
           logError("Create partition data writer failed", e)
@@ -801,6 +808,19 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
   }
 
   def close(exitKind: Int): Unit = {
+    if (hadoopFs != null) {
+      hadoopFs.asScala.foreach {
+        case (storageType, fs) =>
+          if (fs != null) {
+            try {
+              fs.close()
+            } catch {
+              case t: Throwable =>
+                logError(s"Close $storageType FileSystem ${fs.getUri} failed.", t)
+            }
+          }
+      }
+    }
     if (db != null) {
       if (exitKind == CelebornExitKind.WORKER_GRACEFUL_SHUTDOWN) {
         try {
@@ -1126,7 +1146,7 @@ final private[worker] class StorageManager(conf: CelebornConf, workerSource: Abs
           fileName,
           s3FileInfo)
         return (s3Flusher.get, s3FileInfo, null)
-      } else if (hasOssStorage && location.getStorageInfo.OSSAvailable()) {
+      } else if (dirs.isEmpty && location.getStorageInfo.OSSAvailable()) {
         val shuffleDir =
           new Path(new Path(ossDir, conf.workerWorkingDir), s"$appId/$shuffleId")
         FileSystem.mkdirs(
