@@ -155,7 +155,7 @@ abstract class TierWriterBase(
       waitTime -= WAIT_INTERVAL_MS
     }
     if (counter.get > 0 && failWhenTimeout) {
-      val ioe = new IOException("Wait pending actions timeout.")
+      val ioe = new IOException(s"Wait pending actions timeout after $writerCloseTimeoutMs ms.")
       notifier.setException(ioe)
       throw ioe
     }
@@ -407,7 +407,7 @@ class LocalTierWriter(
 
   override def genFlushTask(finalFlush: Boolean, keepBuffer: Boolean): FlushTask = {
     notifier.numPendingFlushes.incrementAndGet()
-    new LocalFlushTask(flushBuffer, channel, notifier, true, gatherApiEnabled)
+    new LocalFlushTask(flushBuffer, channel, notifier, true, source, gatherApiEnabled)
   }
 
   override def writeInternal(buf: ByteBuf): Unit = {
@@ -587,12 +587,13 @@ class DfsTierWriter(
   override def genFlushTask(finalFlush: Boolean, keepBuffer: Boolean): FlushTask = {
     notifier.numPendingFlushes.incrementAndGet()
     if (hdfsFileInfo.isHdfs) {
-      new HdfsFlushTask(flushBuffer, hdfsFileInfo.getDfsPath(), notifier, true)
+      new HdfsFlushTask(flushBuffer, hdfsFileInfo.getDfsPath(), notifier, true, source)
     } else if (hdfsFileInfo.isOSS) {
       val flushTask = new OssFlushTask(
         flushBuffer,
         notifier,
         true,
+        source,
         ossMultipartUploadHandler,
         partNumber,
         finalFlush)
@@ -603,6 +604,7 @@ class DfsTierWriter(
         flushBuffer,
         notifier,
         true,
+        source,
         s3MultipartUploadHandler,
         partNumber,
         finalFlush)
@@ -664,7 +666,14 @@ class DfsTierWriter(
   override def notifyFileCommitted(): Unit =
     storageManager.notifyFileInfoCommitted(shuffleKey, filename, hdfsFileInfo)
 
-  override def closeResource(): Unit = {}
+  override def closeResource(): Unit = {
+    if (s3MultipartUploadHandler != null) {
+      s3MultipartUploadHandler.close()
+    }
+    if (ossMultipartUploadHandler != null) {
+      ossMultipartUploadHandler.close()
+    }
+  }
 
   override def cleanLocalOrDfsFiles(): Unit = {
     hdfsFileInfo.deleteAllFiles(hadoopFs)
