@@ -110,12 +110,16 @@ trait ReadWriteTestBase extends AnyFunSuite
       0,
       0,
       0,
+      0,
       Integer.MAX_VALUE,
       null,
       null,
       null,
       null,
-      metricsCallback)
+      null,
+      null,
+      metricsCallback,
+      true)
     val outputStream = new ByteArrayOutputStream()
 
     var b = inputStream.read()
